Aider has special support for providing
OpenAI and Anthropic API keys
via 
[command line switches](/docs/config/options.html)
and 
[yaml config file](/docs/config/aider_conf.html).
*All other LLM providers* must 
have their keys and settings 
specified in environment variables.
This can be done in your shell, 
or by using a 
[.env file](/docs/config/dotenv.html).
